@@ -1,7 +1,7 @@
 #ifndef CONTROL_H
 #define CONTROL_H
 
-#include <QObject>
+#include <QMainWindow>
 #include <QMainWindow>
 #include <QStandardItemModel>
 #include "booklistwidget.h"
@@ -9,14 +9,15 @@
 
 class QModelIndex;
 class QStandardItem;
+class AudioBook;
 
-class Control : public QObject
+class Control : public QMainWindow
 {
     Q_OBJECT
 
 public:
 
-    Control( QObject* aParent = 0);
+    Control( QWidget* aParent = 0);
 
     ~Control();
 
@@ -38,11 +39,15 @@ private slots:
 
     bool isBookAdded( const QString& aBookName );
 
+    void bookClosed( AudioBook* book);
+
+    void bookPaused(AudioBook* book);
+
 private:
 
-    QStandardItemModel mBookListModel;
-    BookListWidget mBookListWidget;
-    ReadWidget mReadWidget;
+    QStandardItemModel *mBookListModel;
+    BookListWidget *mBookListWidget;
+    ReadWidget *mReadWidget;
 };
 
 #endif // CONTROL_H
