@@ -7,9 +7,10 @@
 int main(int argc,char* argv[])
 {
     QApplication app(argc,argv);
-    app.setApplicationName("audiobookreader");        
+    app.setApplicationName("AudiobookReader");
 
-    new Control( qApp );
+    Control controlWindow;
+    //controlWindow.show();
 
     app.exec();
 }
